#!/usr/bin/env python
"""
Doit task manager for making sampling evaluation plots for schemes.
"""

from itertools import product

SCHEMES = ["3", "4", "MBN", "ARG", ]
EXPS = ["MARC_main", "MARC_gCCN", ]
PLOTS = ['oneone', 'dists']
VAR_SETTINGS = {
    'Smax': {
        'lims': [1e-5, 1.0],
    },
    'Nderiv': {
        'lims': [0.1, 1e4],
    },
}
VARS = VAR_SETTINGS.keys()


def task_plot():
    """ Make all combinations of sampling plots. """

    for scheme, exp, plot, var in product(SCHEMES, EXPS, PLOTS, VARS):
        var_setting = VAR_SETTINGS[var]
        reference = "{}_LHS_design".format(exp)

        scheme_full = "expansion_order_"+scheme if scheme in ["3", "4"] \
                      else scheme
        out_fn = "figs/{}_{}_{}_{}.png".format(plot, var, scheme_full,
                                               reference)
        dependencies = [
            "{}_exp.dict".format(exp),
            "{}_results.dict".format(exp),
            "{}.csv".format(reference),
            "{}_results.csv".format(reference)
        ]
        var_args = []
        for arg, val in var_setting.iteritems():
            var_args.append("--"+arg)
            if hasattr(val, "__iter__"):
                var_args.extend(map(str, val))
            else:
                var_args.append(str(val))

        yield {
            'name': ":".join([scheme, exp, plot, var]),
            'targets': [out_fn, ],
            'file_dep': dependencies,
            'actions': [
                ["python", "pce_vis.py", plot, exp,
                 "-r", reference, "-s", scheme, "-v", var, ] + var_args,
            ],
        }
